==> vip_zone.3.2.zip: lang/fr.php <==
<?php
$LANG = array (

		# config.php
		'L_PROFIL_VISITOR' 						=> 'VIP' ,
		'L_LOAD_VIP_POSITION'					=>'Position de chargement du plugin',
		'L_LOAD_VIP_FIRST'						=> 'Charger ce plugin avant les autres.',
		'L_LOAD_VIP_WARNING'					=> 'A utiliser en cas de dysfonctionnement d\'autres plugins en configuration "Pages Statiques"',
		

		'L_VIP_ZONE_SELECTION'	 				=> 'Selectionnez l\'espace VIP',
		'L_VIP_ZONE_PRIVATIZED'					=> 'Espace privatisé',
		'L_ZONE_NONE2' 							=> 'Aucune',
		'L_ZONE_BLOG'							=> 'Blog',
		'L_ZONE_CAT_ART' 						=> 'Pages Categories et Articles',
		'L_ZONE_STATIC' 						=> 'Pages Statiques',		
		'L_SAVE_VIP_ZONE_SELECTED' 				=> 'Validez la zone selectionnée',
		'L_UNSET_PRIVATE_ZONE_BLOG_TO_NONE' 	=> 'configuration blog incompatible,<br> selectonnez un autre mode.',
		'L_UNSET_PRIVATE_ZONE_STATIC_TO_NONE' 	=> 'configuration statique incompatible,<br> selectonnez un autre mode.',
		
		'L_NEW_STATIC_VIP'						=> 'Créez une page Statique privée',
		'L_DO_UPDATE_NEW_VIP_STAT'				=> 'Pour editer et activer la nouvelle page statique privatisée, rendez vous à:',
		'L_NOT_FIRST_LINE'						=> 'Ne pas éditer ni enlever la  première ligne de code, l\'édition de votre page statique commence ici.',
		
		'L_BATCH_NEW_VIPS' 						=> 'Ajout par lot Utilisateur(s) VIP(s)',
		'L_BATCH_FILE_DIRECTORY' 				=> 'Emplacement du fichier',
		'L_SAVE_VIP_PROFILE_FILE_ONLINE'		=> 'Modifiez la liste utilisateur(s) en ligne',
		'L_UPLOAD_NEW_CSV_FILE' 				=> 'Envoyer et mettre à jour avec mon fichier username.csv',
		'L_INFO_CONFIG_PLUGIN' 					=> 'Infos configuration',
		'L_UPDATE_NEW_USERS_CSV'				=> 'Validez l\'ajout de nouveaux utilisateurs.(MAJ: username.csv)' ,
		'L_NBR_REGISTERED_VIP'					=> 'Nombre d\'utilisateurs V.I.P. ',
		'L_NBR_REGISTERED_ACTIVE_VIP'			=> 'Nombre d\'utilisateur(s) V.I.P. activé(s)',
		'L_NBR_STATIC_VIP'						=> 'Nombre de page(s) statique(s) privée(s)',
		'L_CLASS_FOR_BODY'						=> '<code>class</code> hors connexion ajoutée à <code>body</code>',
		
		'L_USER_FILE' 							=> 'fichier configuration utilisateur(s)',
		'L_BACKUP_USER_FILE_FIRST_INSTALL' 		=> 'backup du fichier utilisateur à la  première activation du plugin',
		'L_BATCH_FILE_NAME_DIRECTORY' 			=> 'Nom et emplacement du fichier CSV (enregistrement par lot)',
		'L_ERROR_BATCH_RECORDS'					=> 'Format enregistrement utilisateur incorrect à la ligne (champ manquant):'	,
		'L_UPDATE_USERS_SUCCESSFUL'				=> 'Mise à jour des données effectuée avec succès',
		'L_DL_101_CSV_FILE' 					=> 'telecharger le fichier CSV  modéle.',
		'L_ON_LINE'								=> ' à la ligne',
		
		'L_VIP_LOGOUT' 							=> 'Déconnexion',
		'L_VIP_LOGOUT_TITLE' 					=> 'Se deconnecter de l\'espace V.I.P.',
		'L_LOGIN_PAGE_VIP' 						=> 'Connexion à l\'espace privé',
		
		// parse article
		'L_HIDDEN_STATIC'						=>'<p class="red alert xy-center">Vous devez être connecté pour visualisé ce contenu.</p>',
		'L_HIDDEN_ARTICLE'						=>'<p class="red alert xy-center">Vous devez être connecté pour visualisé ce contenu<br> Cliquer sur le titre de l\'article pour vous connecter.</p>',
		'L_HIDDEN_ARTICLE_BLOG'					=>'<p class="red alert xy-center">Vous devez être connecté au <b>blog</b><br>pour visualiser ce contenu.</p>',
		'L_HIDDEN_COMMENT'						=>'<p class="orange alert">Vous devez être connecté pour visualiser ce commentaire.</p>'
);

==> vip_zone.3.3.zip: lang/fr.php <==
<?php
$LANG = array (

		# config.php
		'L_PROFIL_VISITOR' 						=> 'VIP' ,
		'L_LOAD_VIP_POSITION'					=>'Position de chargement du plugin',
		'L_LOAD_VIP_FIRST'						=> 'Charger ce plugin avant les autres.',
		'L_LOAD_VIP_WARNING'					=> 'A utiliser en cas de dysfonctionnement d\'autres plugins en configuration "Pages Statiques"',
		

		'L_VIP_ZONE_SELECTION'	 				=> 'Selectionnez l\'espace VIP',
		'L_VIP_ZONE_PRIVATIZED'					=> 'Espace privatisé',
		'L_ZONE_NONE2' 							=> 'Aucune',
		'L_ZONE_BLOG'							=> 'Blog',
		'L_ZONE_CAT_ART' 						=> 'Pages Categories et Articles',
		'L_ZONE_STATIC' 						=> 'Pages Statiques',		
		'L_SAVE_VIP_ZONE_SELECTED' 				=> 'Validez la zone selectionnée',
		'L_UNSET_PRIVATE_ZONE_BLOG_TO_NONE' 	=> 'configuration blog incompatible,<br> selectonnez un autre mode.',
		'L_UNSET_PRIVATE_ZONE_STATIC_TO_NONE' 	=> 'configuration statique incompatible,<br> selectonnez un autre mode.',
		
		'L_NEW_STATIC_VIP'						=> 'Créez une page Statique privée',
		'L_DO_UPDATE_NEW_VIP_STAT'				=> 'Pour editer et activer la nouvelle page statique privatisée, rendez vous à:',
		'L_NOT_FIRST_LINE'						=> 'Ne pas éditer ni enlever la  première ligne de code, l\'édition de votre page statique commence ici.',
		
		'L_BATCH_NEW_VIPS' 						=> 'Ajout par lot Utilisateur(s) VIP(s)',
		'L_BATCH_FILE_DIRECTORY' 				=> 'Emplacement du fichier',
		'L_SAVE_VIP_PROFILE_FILE_ONLINE'		=> 'Modifiez la liste utilisateur(s) en ligne',
		'L_UPLOAD_NEW_CSV_FILE' 				=> 'Envoyer et mettre à jour avec mon fichier username.csv',
		'L_INFO_CONFIG_PLUGIN' 					=> 'Infos configuration',
		'L_UPDATE_NEW_USERS_CSV'				=> 'Validez l\'ajout de nouveaux utilisateurs.(MAJ: username.csv)' ,
		'L_NBR_REGISTERED_VIP'					=> 'Nombre d\'utilisateurs V.I.P. ',
		'L_NBR_REGISTERED_ACTIVE_VIP'			=> 'Nombre d\'utilisateur(s) V.I.P. activé(s)',
		'L_NBR_STATIC_VIP'						=> 'Nombre de page(s) statique(s) privée(s)',
		'L_CLASS_FOR_BODY'						=> '<code>class</code> hors connexion ajoutée à <code>body</code>',
		
		'L_USER_FILE' 							=> 'fichier configuration utilisateur(s)',
		'L_BACKUP_USER_FILE_FIRST_INSTALL' 		=> 'backup du fichier utilisateur à la  première activation du plugin',
		'L_BATCH_FILE_NAME_DIRECTORY' 			=> 'Nom et emplacement du fichier CSV (enregistrement par lot)',
		'L_ERROR_BATCH_RECORDS'					=> 'Format enregistrement utilisateur incorrect à la ligne (champ manquant):'	,
		'L_UPDATE_USERS_SUCCESSFUL'				=> 'Mise à jour des données effectuée avec succès',
		'L_DL_101_CSV_FILE' 					=> 'telecharger le fichier CSV  modéle.',
		'L_ON_LINE'								=> ' à la ligne',
		
		'L_VIP_LOGOUT' 							=> 'Déconnexion',
		'L_VIP_LOGOUT_TITLE' 					=> 'Se deconnecter de l\'espace V.I.P.',
		'L_LOGIN_PAGE_VIP' 						=> 'Connexion à l\'espace privé',
		
		// parse article
		'L_HIDDEN_STATIC'						=>'<p class="red alert xy-center">Vous devez être connecté pour visualisé ce contenu.</p>',
		'L_HIDDEN_ARTICLE'						=>'<p class="red alert xy-center">Vous devez être connecté pour visualisé ce contenu<br> Cliquer sur le titre de l\'article pour vous connecter.</p>',
		'L_HIDDEN_ARTICLE_BLOG'					=>'<p class="red alert xy-center">Vous devez être connecté au <b>blog</b><br>pour visualiser ce contenu.</p>',
		'L_HIDDEN_COMMENT'						=>'<p class="orange alert">Vous devez être connecté pour visualiser ce commentaire.</p>',
		'L_HIDDEN_COMMENTS'						=>'<p class="orange alert">Vous devez être connecté pour visualiser les commentaires.</p>',
		'L_HIDDEN_AUTHOR'						=>'Anonymous',
);
